/* Actions.cs
   Copyright (C) 2006 Pageflex and Bitstream Inc. All rights reserved.

History:
  08.30.2006 rm   Created.
*/

using System;
using Pageflex.Scripting;
using Pageflex.Scripting.Exceptions;
//using System.Data.OleDb;
//using System.Data;
//using System.IO;


public class Actions
{
    // Increase or decrease font size of currently-selected text
    static public void BumpFontSize(string fontSizeDelta)
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        Document doc = Application.CurrentDocument;
        doc.BeginUndoSection(null);

        Range range = null;
        string message = "";
        if (Application.SelectedRange != null)
        {
            // Text is selected, so use it
            range = Application.SelectedRange;
        }
        else if (Application.SelectedShapes.Length == 1 &&
                 Application.SelectedShapes[0] is ITextContainer)
        {
            // A text container is selected, so use its text
            range = ((ITextContainer)Application.SelectedShapes[0]).Contents;
        }
        else
            message = "Please select some text or a text container.";

        if (range != null)
        {
            try
            {
                // The selected range may have different font sizes, so handle each separately
                foreach (Range subrange in range.ContentRanges)
                    subrange.FontSize += fontSizeDelta;
            }
            catch (InvalidMeasurementException)
            {
                message = "Could not parse fontSizeDelta. Use a number with units, such as '2pt'.";
            }
            catch (ValueTooSmallException)
            {
                message = "Cannot decrease font size lower than 0.1pt.";
            }
        }
        doc.EndUndoSection();

        // Inform client of error message via a user string
        Application.SetUserString("DocumentActionError", message, false);

        if (message != "")
            // Undo any changes we made
            doc.Undo();
    }

    static public void SetBackColor(string backgroundcolor, string AreaTemplateName)
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        Document doc = Application.CurrentDocument;
        Element e = doc.FindElement(AreaTemplateName);
        if (e != null)
        {
            ((AreaTemplate)e).FillColor = backgroundcolor;
            Application.Log(((AreaTemplate)e).Name);
            Application.Log(((AreaTemplate)e).FillColor);
        }

    }

	static public void RotateShape(string ElementName, string Angle)
    {
        Document doc = Application.CurrentDocument;
        Element e = doc.FindElement(ElementName);
        if (e != null && e is Shape && e.IsVisible)
        {
			double dblAngle = 0;
			double.TryParse(Angle,out dblAngle);
            ((Shape)e).Angle = dblAngle;
        }
    }
	
	static public void MoveShape(string ElementName, string X, string Y)
    {
        Document doc = Application.CurrentDocument;
        Element e = doc.FindElement(ElementName);
        if (e != null && e is Shape && e.IsVisible)
        {
            ((Shape)e).X = X;
            ((Shape)e).Y = Y;
        }
    }

	static public void ResizeShape(string ElementName, string Width, string Height)
    {
        Document doc = Application.CurrentDocument;
        Element e = doc.FindElement(ElementName);
        if (e != null && e is Shape && e.IsVisible)
        {
            ((Shape)e).Width = Width;
            ((Shape)e).Height = Height;
        }
    }
	
    static public void SetBackColorAllPages(string backgroundcolor, string AreaTemplateName)
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        Document doc = Application.CurrentDocument;
        for (uint index = 1; index <= doc.PageCount; index++)
        {
            try
            {
                Page page = doc.GetPage(index);
                Element e = page;
                Element sentinelElement = e.NextNonDescendantElementInTree;
                for (Element n = e; n != sentinelElement; n = n.NextElementInTree)
				{
                    if (n is AreaTemplate)
					{
						if (((AreaTemplate)n).Name == AreaTemplateName)
						((AreaTemplate)n).FillColor = backgroundcolor;
					}

				}
                // Element e = page.FindElement(AreaTemplateName);
                // if (e != null)
                // {
                    // ((AreaTemplate)e).FillColor = backgroundcolor;
                    // Application.Log(((AreaTemplate)e).Name);
                    // Application.Log(((AreaTemplate)e).FillColor);
                // }
            }
            catch (ElementNotFoundException ex)
            {
                Application.Log(ex.Message);
            }


        }


    }

    static public void SetBorderColorAllPages(string backgroundcolor, string AreaTemplateName)
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        Document doc = Application.CurrentDocument;
        for (uint index = 1; index <= doc.PageCount; index++)
        {
            try
            {

                Page page = doc.GetPage(index);
                Element e = page.FindElement(AreaTemplateName);
                if (e != null)
                {
                    ((AreaTemplate)e).BorderColor = backgroundcolor;
                    Application.Log(((AreaTemplate)e).Name);
                    Application.Log(((AreaTemplate)e).FillColor);
                }
            }
            catch (ElementNotFoundException ex)
            {
                Application.Log(ex.Message);
            }


        }


    }

	    static public void SetTextFramePropertiesForAllPages(string FontFamily, string FontFamilyTextFrameNames, string TextColor, string TextColorTextFrameNames, string BorderColor, string BorderColorTextFrameNames, string BackColor, string BackColorTextFrameNames, string FontSize, string FontSizeTextFrameNames)
    {
        Document doc = Application.CurrentDocument;
		string[] arrFontTextFrames = FontFamilyTextFrameNames.Split(';');
		string[] arrTextColorTextFrames = TextColorTextFrameNames.Split(';');
		string[] arrBorderColorTextFrames = BorderColorTextFrameNames.Split(';');
		string[] arrBackColorTextFrames = BackColorTextFrameNames.Split(';');
        string[] arrFontSizeTextFrames = FontSizeTextFrameNames.Split(';');
		
        for (uint index = 1; index <= doc.PageCount; index++)
        {
            try
            {
                Page page = doc.GetPage(index);

                Element e = page;
                Element sentinelElement = e.NextNonDescendantElementInTree;
                for (Element n = e; n != sentinelElement; n = n.NextElementInTree)
                {
                    if (n is TextFrame)
                    {
                        TextFrame i = (TextFrame)n;
						foreach (string strFontTextFrame in arrFontTextFrames)
						{
							if (i.IsVisible && i.Name == strFontTextFrame && !string.IsNullOrEmpty(strFontTextFrame))
							{
								try
								{
									Range objRange = ((TextFrame)i).Contents;
									if (objRange != null)
									{
										foreach (TextElement objText in objRange.ContentElements)
										{
											objText.FontFamily = FontFamily;
										}
									}
								}
								catch (Exception)
								{
								}
							}

						}
                        foreach (string strFontSizeTextFrame in arrFontSizeTextFrames)
                        {
                            if (i.IsVisible && i.Name == strFontSizeTextFrame && !string.IsNullOrEmpty(strFontSizeTextFrame))
                            {
                                try
                                {
                                    Range objRange = ((TextFrame)i).Contents;
                                    if (objRange != null)
                                    {
                                        foreach (TextElement objText in objRange.ContentElements)
                                        {
                                            objText.FontSize = FontSize;
                                        }
                                    }
                                }
                                catch (Exception)
                                {
                                }
                            }

                        }
						foreach (string strTextColorTextFrame in arrTextColorTextFrames)
						{
							if (i.IsVisible && i.Name == strTextColorTextFrame && !string.IsNullOrEmpty(strTextColorTextFrame))
							{
								try
								{
									Range objRange = ((TextFrame)i).Contents;
									if (objRange != null)
									{
										foreach (TextElement objText in objRange.ContentElements)
										{
											objText.TextColor = TextColor;
										}
									}
								}
								catch (Exception)
								{
								}
							}

						}
						foreach (string strBorderColorTextFrame in arrBorderColorTextFrames)
						{
							if (i.IsVisible && i.Name == strBorderColorTextFrame && !string.IsNullOrEmpty(strBorderColorTextFrame))
							{
								try
								{
									i.BorderColor = BorderColor;
								}
								catch (Exception)
								{
								}
							}

						}
						foreach (string strBackColorTextFrame in arrBackColorTextFrames)
						{
							if (i.IsVisible && i.Name == strBackColorTextFrame && !string.IsNullOrEmpty(strBackColorTextFrame))
							{
								try
								{
									i.FillColor = BackColor;
								}
								catch (Exception)
								{
								}
							}

						}

                    }
                }
            }
            catch (ElementNotFoundException ex)
            {
                Application.Log(ex.Message);
            }
            catch (StaleScriptingObjectException ex)
            {
                Application.Log(ex.Message);
            }
        }
    }

	
    static public void SetFontFamilyForAllPages(string AreaTemplateName, string FontFamily, string TextFrameName)
    {
        bool bCheckForTextFrameMatch = false;
        if (!string.IsNullOrEmpty(TextFrameName))
        {
            bCheckForTextFrameMatch = true;
        }
        Document doc = Application.CurrentDocument;
        for (uint index = 1; index <= doc.PageCount; index++)
        {
            try
            {

                Page page = doc.GetPage(index);

                Element e = null;
                if (!string.IsNullOrEmpty(AreaTemplateName))
                    e = page.FindElement(AreaTemplateName);
                else
                {
                    e = page;
                    try
                    {
                        Element tmpCheck = page.FindElement(TextFrameName);
                    }
                    catch (ElementNotFoundException)
                    {
                        continue;
                    }
                }
                Element sentinelElement = e.NextNonDescendantElementInTree;
                for (Element n = e; n != sentinelElement; n = n.NextElementInTree)
                {
                    if (n is TextFrame)
                    {
                        TextFrame i = (TextFrame)n;
                        if (i.IsVisible && i.Name != AreaTemplateName && (!bCheckForTextFrameMatch || (bCheckForTextFrameMatch && i.Name == TextFrameName)))
                        {
                            try
                            {
                                Range objRange = ((TextFrame)i).Contents;
                                if (objRange != null)
                                {
                                    foreach (TextElement objText in objRange.ContentElements)
                                    {
                                        objText.FontFamily = FontFamily;
                                    }
                                }
                            }
                            catch (Exception)
                            {
                            }
                        }
                    }
                }
            }
            catch (ElementNotFoundException ex)
            {
                Application.Log(ex.Message);
            }
            catch (StaleScriptingObjectException ex)
            {
                Application.Log(ex.Message);
            }
        }
    }

    static public void SetTextColorForAllPages(string AreaTemplateName, string TextColor, string TextFrameName)
    {
        bool bCheckForTextFrameMatch = false;
        if (!string.IsNullOrEmpty(TextFrameName))
        {
            bCheckForTextFrameMatch = true;
        }
        Document doc = Application.CurrentDocument;
        for (uint index = 1; index <= doc.PageCount; index++)
        {
            try
            {

                Page page = doc.GetPage(index);
                Element e = null;
                if (!string.IsNullOrEmpty(AreaTemplateName))
                    e = page.FindElement(AreaTemplateName);
                else
                {
                    e = page;
                    try
                    {
                        Element tmpCheck = page.FindElement(TextFrameName);
                    }
                    catch (ElementNotFoundException)
                    {
                        continue;
                    }
                }
                Element sentinelElement = e.NextNonDescendantElementInTree;
                for (Element n = e; n != sentinelElement; n = n.NextElementInTree)
                {
                    if (n is TextFrame)
                    {
                        TextFrame i = (TextFrame)n;
                        if (i.IsVisible && i.Name != AreaTemplateName && (!bCheckForTextFrameMatch || (bCheckForTextFrameMatch && i.Name == TextFrameName)))
                        {
                            try
                            {
                                Range objRange = ((TextFrame)i).Contents;
                                if (objRange != null)
                                {
                                    foreach (TextElement objText in objRange.ContentElements)
                                    {
                                        objText.TextColor = TextColor;
                                    }
                                    //foreach (Paragraph objPara in objRange.Paragraphs)
                                    //{
                                    //    objPara.TextColor = TextColor;
                                    //}
                                }
                            }
                            catch (Exception)
                            {
                            }
                        }
                    }
                }
            }
            catch (ElementNotFoundException ex)
            {
                Application.Log(ex.Message);
            }
            catch (StaleScriptingObjectException ex)
            {
                Application.Log(ex.Message);
            }

        }
    }

    static public void SetBackColorTextBoxForAllPages(string AreaTemplateName, string BackColor, string TextFrameName)
    {
        bool bCheckForTextFrameMatch = false;
        if (!string.IsNullOrEmpty(TextFrameName))
        {
            bCheckForTextFrameMatch = true;
        }
        Document doc = Application.CurrentDocument;
        for (uint index = 1; index <= doc.PageCount; index++)
        {
            try
            {
                Page page = doc.GetPage(index);

                Element e = null;
                if (!string.IsNullOrEmpty(AreaTemplateName))
                    e = page.FindElement(AreaTemplateName);
                else
                {
                    e = page;
                    try
                    {
                        Element tmpCheck = page.FindElement(TextFrameName);
                    }
                    catch (ElementNotFoundException)
                    {
                        continue;
                    }
                }
                Element sentinelElement = e.NextNonDescendantElementInTree;
                for (Element n = e; n != sentinelElement; n = n.NextElementInTree)
                {
                    if (n is TextFrame)
                    {
                        TextFrame i = (TextFrame)n;
                        if (i.IsVisible && i.Name != AreaTemplateName && (!bCheckForTextFrameMatch || (bCheckForTextFrameMatch && i.Name == TextFrameName)))
                        {
                            i.FillColor = BackColor;
                        }
                    }
                }
            }
            catch (ElementNotFoundException ex)
            {
                Application.Log(ex.Message);
            }
            catch (StaleScriptingObjectException ex)
            {
                Application.Log(ex.Message);
            }
        }
    }


    static public void SetGridColors(string AreaTemplateName)
    {
        // Find all images in document
        try
        {
            Variable var = Application.GetVariable("Avdelingsnavn");
            Document doc = Application.CurrentDocument;
            Element e = doc.FindElement(AreaTemplateName);
            int index = 0;
            string color1 = "";
            string color2 = "";
            if (var.Value == "Telenor") //Telenor
            {
                color1 = "Telenor1";
                color2 = "Telenor2";
            }
            else if (var.Value == "djuice") //DJUICE
            {
                color1 = "DJUICE1";
                color2 = "DJUICE2";
            }
            Element sentinelElement = e.NextNonDescendantElementInTree;
            for (Element n = e; n != sentinelElement; n = n.NextElementInTree)
            {
                if (n is AreaTemplate)
                {
                    AreaTemplate i = (AreaTemplate)n;
                    if (i.IsVisible && i.Name != AreaTemplateName)
                    {
                        if (index % 2 == 0)
                            i.FillColor = color1;
                        else
                            i.FillColor = color2;
                        index++;
                    }
                }
            }
        }
        catch (ElementNotFoundException ex)
        {
            Application.Log(ex.Message);
        }
    }

    static public void AddSize()
    {
        double[] arrSizes = { 71, 107, 144, 181, 218, 254, 291, 365 };
        Document doc = Application.CurrentDocument;
        foreach (double newSize in arrSizes)
        {
            doc.PageHeight = new Measurement(newSize, Measurement.Units.Mm);
            ITextContainer[] arrTextContainer = doc.OverflowingTextContainers;
            if (arrTextContainer.Length == 0)
            {
                break;
            }
        }
    }
    static public void AutoSize()
    {
        double HeightDelta = 3.5;
        Document doc = Application.CurrentDocument;
        double newSize = 1;
        doc.PageHeight = new Measurement(newSize, Measurement.Units.Mm);
        while (doc.OverflowingTextContainers.Length > 0)
        {
            newSize += HeightDelta;
            doc.PageHeight = new Measurement(newSize, Measurement.Units.Mm);
        }
    }
    static public void ChangeSize()
    {
        Variable varWIDTH = Application.GetVariable("WIDTH");
        Variable varHEIGHT = Application.GetVariable("HEIGHT");
        double dblWidth = double.Parse(varWIDTH.Value);
        double dblHeight = double.Parse(varHEIGHT.Value);
        Document doc = Application.CurrentDocument;
        doc.PageHeight = new Measurement(dblHeight, Measurement.Units.Mm);
        doc.PageWidth = new Measurement(dblWidth, Measurement.Units.Mm);
    }

    // Add a page based on a SourcePage (page number)
    static public void AddPage(string sourcePage)
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        string[] arrArgs = sourcePage.Split('|');
        string masterPage = arrArgs[0]; // e.g: Master_B
        string currentPage = arrArgs[1]; //e.g: 4
        Document doc = Application.CurrentDocument;
        Page pageCurrent = (Page)doc.GetPage(uint.Parse(currentPage));
        //Page pageSibling = (Page)doc.GetPage(uint.Parse(currentPage) + 1);
        //Element parent = pageCurrent.ParentElement;
        //Element sibling = pageCurrent.NextSiblingElement;
        //Page sourceElement = doc.GetPage(sourcePage);
        //pageCurrent.Delete();
        Page newPage = new Page(masterPage);
        //Page newPage2 = (Page)newPage.Duplicate();
        //newPage.MoveBefore(pageCurrent.ParentElement, pageCurrent.NextSiblingElement);
        //Application.MergeData();

        doc.UpdateTablesOfContents();

    }

    // Add a page based on a SourcePage (page number)
    static public void MovePageToEnd(string sourcePage)
    {
        //System.Diagnostics.Debugger.Break();

        Document doc = Application.CurrentDocument;
        Page pageCurrent = (Page)doc.GetPage(uint.Parse(sourcePage));
        Element pcOriginal = pageCurrent.FindElement("pagecontainer");
        new Page(pageCurrent.MasterPage);
        Page newPage = doc.GetPage(doc.PageCount);
        Element pcNew = newPage.FindElement("pagecontainer");
        pcNew.Delete();
        pcOriginal.MoveBefore((Element)newPage, null);
        pageCurrent.Delete();
        doc.UpdateTablesOfContents();

    }

    static public void DeletePage(string currentPage)
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        Document doc = Application.CurrentDocument;
        Page pageCurrent = (Page)doc.GetPage(uint.Parse(currentPage));
        pageCurrent.Delete();

        doc.UpdateTablesOfContents();

    }

    static public void SetTextColor(string textcolor, string TextFrameName)
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        Document doc = Application.CurrentDocument;
        try
        {
            Element e = doc.FindElement(TextFrameName);
            if (e != null)
                ((TextFrame)e).Contents.TextColor = textcolor;
        }
        catch (Exception)
        {
            Application.Log("ERROR: SetTextColor | TextFrameName was not found " + TextFrameName);
        }
    }

    static public void SetVariableValueIfTextFrameIsEmpty(string TextFrameName, string VariableName, string VariableValue)
    {
        // Does not work! invalid range if textframe is empty
        Document doc = Application.CurrentDocument;

        try
        {
            Element e = doc.FindElement(TextFrameName);
            Variable var = Application.GetVariable(VariableName);

            if (e != null)
            {
                Range range = ((TextFrame)e).Contents;
                if (range != null)
                {
                    if (string.IsNullOrEmpty(range.Text))
                    {
                        var.Value = VariableValue;
                    }
                }
            }
        }
        catch (Exception)
        {
            Application.Log("ERROR: SetVariableValueIfTextFrameIsEmpty | TextFrameName was not found " + TextFrameName);
        }

    }

    static public void SetFontSize(string fontsize, string TextFrameName)
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        Document doc = Application.CurrentDocument;
        try
        {
            Element e = doc.FindElement(TextFrameName);
            if (e != null && !string.IsNullOrEmpty(fontsize))
            {
                Range objRange = ((TextFrame)e).Contents;
                if (objRange != null)
                {
                    foreach (Paragraph objPara in objRange.Paragraphs)
                    {
                        objPara.FontSize = fontsize;
                    }
                }
            }
        }
        catch (Exception)
        {
            Application.Log("ERROR: SetFontSize | TextFrameName was not found " + TextFrameName);
        }
    }


    static public void SetFontFamily(string fontfamily, string TextFrameName)
    {
        //System.Diagnostics.Debugger.Break();

        // If we hit an error we'll want to undo any changes, so start an undo section
        Document doc = Application.CurrentDocument;

        try
        {
            Element e = doc.FindElement(TextFrameName);
            if (e != null && !string.IsNullOrEmpty(fontfamily))
            {
                Range objRange = ((TextFrame)e).Contents;
                if (objRange != null)
                {
                    foreach (Paragraph objPara in objRange.Paragraphs)
                    {
                        objPara.FontFamily = fontfamily;
                    }
                }
            }
        }
        catch (Exception)
        {
            Application.Log("ERROR: SetFontFamily | TextFrameName was not found " + TextFrameName);
        }

    }

    static public void SetTextColorVar(string TextFrameName)
    {
        // Find all texframes in document
        Variable var = Application.GetVariable("COLOR");
        Document doc = Application.CurrentDocument;
        try
        {
            Element e = doc.FindElement(TextFrameName);
            if (e != null)
                ((TextFrame)e).Contents.TextColor = var.Value;
        }
        catch (Exception)
        {
            Application.Log("ERROR: SetTextColorVar | TextFrameName was not found " + TextFrameName);
        }

    }

    static public void addWatermarkForPage(string imagePath, string PageNumber)
    {
        Pageflex.Scripting.Document MyDoc = (Pageflex.Scripting.Document)Application.CurrentDocument;
        Page firstPage = (Page)MyDoc.GetPage(uint.Parse(PageNumber));
        Image imgWaterMark = new Image(firstPage);
        imgWaterMark.Source = imagePath;
        imgWaterMark.Fit = ImageFit.FitImage;
        imgWaterMark.X = new Measurement(0);
        imgWaterMark.Y = new Measurement(0);


    }
    static public void addWatermark(string imagePath)
    {
        Pageflex.Scripting.Document MyDoc = (Pageflex.Scripting.Document)Application.CurrentDocument;
        for (uint i = 1; i <= MyDoc.PageCount; i++)
        {
            Page firstPage = (Page)MyDoc.GetPage(i);
            Image imgWaterMark = new Image(firstPage);
            imgWaterMark.Source = imagePath;
            imgWaterMark.Fit = ImageFit.FitImage;
            imgWaterMark.X = new Measurement(0);
            imgWaterMark.Y = new Measurement(0);

        }

    }

    static public void switchPage()
    {
        Pageflex.Scripting.Document MyDoc = (Pageflex.Scripting.Document)Application.CurrentDocument;
        string pageFormat = Application.GetVariable("PageFormat").Value;
        Page NewPage = new Page(pageFormat);
        Page OldPage = (Page)MyDoc.GetPage(1);
        OldPage.Delete();
        if (pageFormat == "A1")
        {
            MyDoc.PageHeight = "841mm";
            MyDoc.PageWidth = "594mm";
        }
        if (pageFormat == "A2")
        {
            MyDoc.PageHeight = "594mm";
            MyDoc.PageWidth = "420mm";
        }
        if (pageFormat == "A3")
        {
            MyDoc.PageHeight = "420mm";
            MyDoc.PageWidth = "297mm";
        }
        if (pageFormat == "A4")
        {
            MyDoc.PageHeight = "297mm";
            MyDoc.PageWidth = "210mm";
        }
        if (pageFormat == "A5")
        {
            MyDoc.PageHeight = "210mm";
            MyDoc.PageWidth = "148mm";
        }
        if (pageFormat == "A6")
        {
            MyDoc.PageHeight = "148mm";
            MyDoc.PageWidth = "105mm";
        }
        if (pageFormat == "A7")
        {
            MyDoc.PageHeight = "105mm";
            MyDoc.PageWidth = "74mm";
        }
        if (pageFormat == "A8")
        {
            MyDoc.PageHeight = "74mm";
            MyDoc.PageWidth = "52mm";
        }
        if (pageFormat == "A9")
        {
            MyDoc.PageHeight = "52mm";
            MyDoc.PageWidth = "37mm";
        }
        if (pageFormat == "A10")
        {
            MyDoc.PageHeight = "37mm";
            MyDoc.PageWidth = "26mm";
        }
    }
}
